import json
from lcconfig import ConsoleSettingsConfig
import logging.config
import os
import sys
import yaml

csc = ConsoleSettingsConfig().load()
console_config = csc.as_typed_dict('BoxData')
PORTAL_CODE_NAME = os.environ['PORTAL_CODE_NAME']
PROJECT_ROOT = os.environ['PROJECT_ROOT']
REDWOOD_LOG_DIR = os.environ['REDWOOD_LOG_DIR']

sys.path.insert(0, PROJECT_ROOT)

try:
    # logtailer is installed before drawbridge_portal, portal_app
    # won't exist on initial install, so don't crash
    from celery_init import portal_app
except (ImportError, ModuleNotFoundError):
    portal_app = object

from console_settings import (
    CACHES,
    cache_key,
    CONSOLE_GID,
    CONSOLE_UID,
    DATETIME_FMT,
    DNS_LOGLINE_FIELDS,
    IS_DRAWBRIDGE_OS,
    LC_CAT_PREFIX,
    NON_SCORERS,
    REDIS_SOCKET,
    REDWOOD_LOG_FIELDS,
    TLS_LOG_FIELDS,
)

# Number of log lines to buffer before POSTing to console
BUFFER_LINES = 500

# Cache settings that are shared between Console
# and logtailer process, to share data between them
CACHE_DATABASE = CACHES['default']['OPTIONS']['DB']
CACHE_PREFIX = CACHES['default']['KEY_PREFIX']
PICKLE_VERSION = CACHES['default']['OPTIONS']['PICKLE_VERSION']

HOSTNAME = console_config.get('hostname')
FILTER_SERVER = console_config.get('filter_server', True)
CLOUD_SERVER = console_config.get('cloud_server', True)
AUTH_TOKEN = console_config.get('auth_token', '')


def load_centrifugo_config():

    try:
        with open('/etc/centrifugo/config.json', 'r') as csf:
            return json.load(csf)
    except FileNotFoundError:
        pass

    with open(f'{PROJECT_ROOT}/privatesettings/centrifugo.yaml', 'r') as csf:
        return yaml.safe_load(csf)


cc = load_centrifugo_config()
WEBSOCKET_PORT = 10100
CENTRIFUGE_SECRET = cc.get('token_hmac_secret_key')
CENTRIFUGE_API_KEY = cc.get('api_key')
CENTRIFUGE_TIMEOUT = 10
CENTRIFUGE_ADDRESS = f'wss://{HOSTNAME}'

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse',
        }
    },
    'formatters': {
        'default_formatter': {
            'format': "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
            'datefmt': DATETIME_FMT,
        },
    },
    'handlers': {
        'file': {
            'level': 'INFO',
            'class': 'logging.FileHandler',
            'filename': f'/var/log/{PORTAL_CODE_NAME}/logtailer.log',
            'formatter': 'default_formatter',
        },
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default_formatter',
        },
    },
    'loggers': {
        'logtailer': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'INFO',
        },
    },
}

logging.config.dictConfig(LOGGING)
